animate_treemap_qc_year: Animate treemap for categorical question over years, write to...

Description Usage Arguments Value

Description

Animate treemap for categorical question over years, write to gif

Usage

1

Arguments

d

data frame from tidy_poll()

q

question with categorical answers

gif

path to output gif

Value

True


bbest/calcoastpoll documentation built on May 6, 2019, 8:08 p.m.